!       SAMKJORINGSNETT FOR XPRESS
!
!
MODEL NETT
!
TABLES
!
 DIMM(2)
!
!
!
DISKDATA
!
 DIMM(1) = nett.dim
!
!       Setter nytt navn paa maksimalverdiene av indeksene      
!
LET TMAX = DIMM(1)       ! Antall typer generatorer, t som indeks for type
LET PMAX = DIMM(2)       ! Antall tidsperioder, p som indeks for periode
!
!       Definerer data for tabeller som er indeksregulerte
!
TABLES
!
 STARTK(TMAX)   ! Kostnader for oppstart av en generator av type t
!
 DRIFTK(TMAX)   ! Kostnader pr time pr MW over min-nivaa for gen. type t
!
 MINKOST(TMAX)  ! Kostnad pr time ved min-nivaa for gen. type t
!
 MAXNIV(TMAX)   ! Maksimalt effektuttak for gen av type t
!
 MINNIV(TMAX)   ! Minimalt effektuttak for gen av type t
!
 LENGDE(PMAX)   ! Antall timer i periode p
!
 ETTERSP(PMAX)  ! Ettersporsel av effekt i periode p
!
 RESERVE        ! Krav til kraftresereve
!
 ANTALL(TMAX)   ! Antall generatorer av type t
!
 TAB(TMAX,PMAX) ! Hjelpeberegninger for maalfunksjonen, beregnet under assign
!
!
!
DISKDATA
!
  STARTK(1)  = nett.sta
  DRIFTK(1)  = nett.dri
  MINKOST(1) = nett.ost
  MAXNIV(1)  = nett.max
  MINNIV(1)  = nett.min
  LENGDE(1)  = nett.len
  ETTERSP(1) = nett.ett
  RESERVE    = nett.res
  ANTALL(1)  = nett.ant
!  
!
!
!       Definerer variablene for de aktuelle indekskombinasjonene
!
VARIABLES
!
 nummer(t=1:TMAX,p=1:PMAX)  ! Antall generatorer i drift av type t i periode p
!
 start(t=1:TMAX,p=1:PMAX)   ! Antall oppstartede generatorer av type t i per.p
!
 effekt(t=1:TMAX,p=1:PMAX)  ! Totalt effektuttak fra generator av type t i per p
!
!
ASSIGN
!
!       Beregning av element i maalfunksjonen.
!
 TAB(t=1:TMAX,p=1:PMAX)                                 &
       = (DRIFTK(t) *  MINNIV(t) -  MINKOST(t)) * LENGDE(p)
!
CONSTRAINTS
!
!       Maalfunksjonen: minimerer kostnadene
!
 MINOBJ:                                                                  &
        SUM(t=1:TMAX,p=1:PMAX)                                            &
         DRIFTK(t) * LENGDE(p) * effekt(t,p)                              &
        - SUM(t=1:TMAX,p=1:PMAX) TAB(t,p) * nummer(t,p)                   &
        + SUM(t=1:TMAX,p=1:PMAX) STARTK(t) * start(t,p)                   $
!                                                                                  
!
!       Begrenser minste effekt fra hver genereator
 MINEFF(t=1:TMAX,p=1:PMAX):                             &
        MINNIV(t) * nummer(t,p) - effekt(t,p) < 0                 
!
!
!       Begrenser maksimale effekt fra hver generator
 MAXEFF(t=1:TMAX,p=1:PMAX):                             &
        effekt(t,p) - MAXNIV(t) * nummer(t,p) < 0                 
!
!
!       Krav til effektreserve
 RESKRAV(p=1:PMAX):                                     &
        RESERVE * ETTERSP(p)                            &
        - SUM(t=1:TMAX) MAXNIV(t) * nummer(t,p) < 0
!
!
!       Antall oppstarter
 OPPSTART(t=1:TMAX,p=2:PMAX):                           &
        nummer(t,p) - nummer(t,p-1) < start(t,p)                      
 OPPSTAR(t=1:TMAX,p=1:1):                               &
        nummer(t,p) - nummer(t,PMAX) < start(t,p)
!
!
!       Angir at total produksjon maa vre lik ettersporselen
 ETTSPOR(p=1:PMAX):                                     &
        ETTERSP(p) - SUM(t=1:TMAX) effekt(t,p) = 0
!
!
BOUNDS
!
!
!
 nummer(t=1:TMAX,p=1:PMAX).UI.ANTALL(t)
!
 start(t=1:TMAX,p=1:PMAX).UI.ANTALL(t)
!
!
GENERATE


