! File plan.mod
!
! Obligatorisk dataoeving i fag 92033 Operasjonsanalyse 2
!
! Levert av Trond M. Andersen, fak. for marinteknikk
!
! *******************************************************
!
! Alle filer forbundet med denne oevingen er paa formen plan.*
!
! *******************************************************
!
MODEL PLAN
!
!
TABLES
!
DIMM(5)          ! Inneholder maksverdier for de tre indeksene samt angivelse
!                  av hvilke modell (12.3 & 12.4) som skal kjoeres
DATA(3)          ! Tabell som inneholder skalare data
!
!
DISKDATA
!
 DIMM(1) = plan.dim
 DATA(1) = plan.dat
!
! Setter nye navn paa maks-verdiene til indeksene
!
LET PMAX  = DIMM(1)     ! Maksimalt antall produkter p [-]
LET TMAX  = DIMM(2)     ! Maksimalt antall maskintyper t [-]
LET MMAX  = DIMM(3)     ! Maksimalt antall tidsperioder (mnd.) m [-]
LET MOD   = DIMM(4)     ! Kjoere modell 12.3 (MOD=1) ellers modell 12.4 
LET NMAX  = DIMM(5)     ! Max antall spesifikke lagerkrav
LET MLKAP = DATA(1)     ! Maksimal lagerkapasitet for alle produkttype [-]
LET KLAG  = DATA(2)     ! Lagerkost. pr. enhet for alle produkttyp. [NOK/time]
LET TPRM  = DATA(3)     ! Timer produksjon per periode (mnd.) [timer/mnd.]
!
! Definerer tabeller for data som er indeksspesifiserte
!
! *************************************************************************
!
!  MOD = 1 dersom man oensker aa kjoere modell 12.3
!  MOD = 0 dersom man oensker aa kjoere modell 12.4
!
! *************************************************************************
!
TABLES
!
! Data som leses direkte fra andre filer
!
 PRO(PMAX)        ! Profitt ved aa produsere en enhet av produkt type p
                  ! = diff. mellom salgsinntekt og raavarekostad [NOK/enhet]
!
 TID(TMAX,PMAX)   ! Prosesseringstid for maskin t ved prosessering
                  ! av produkt p [timer]
!
 VED(MMAX,TMAX)   ! Antall maskiner av typen t nede for vedlikehold i
                  ! periode (mnd.) m [-]
!
 ANTMA(TMAX)      ! Antall maskiner av maskintype t
!
 MABE(MMAX,PMAX)  ! Markedsrestriksjoner for produkt p i tidsperiode m [-]
!
 BEH(NMAX,2)      ! Oensket lagerbeholdning av produkt p i tidsperiodene m [-]
!
! Leser inn verdier til tabellene
!
DISKDATA
!
 PRO(1)         = plan.pro
 TID(1,1)       = plan.tid
 VED(1,1)       = plan.ved
 ANTMA(1)       = plan.ant
 MABE(1,1)      = plan.mab
 BEH(1,1)       = plan.beh
!
! 
! ***************************************************************************
!
! Definerer variable
!
VARIABLES
!
skvant(m=1:MMAX,p=1:PMAX)        ! Solgt kvantum av produkt p i peridoe m 
!
lkvant(m=1:MMAX,p=1:PMAX)        ! Lagret kvantum av produkt p i periode m
!
pkvant(m=1:PMAX,p=1:PMAX)        ! Produsert kvantum av produkt p i perioden m
!
mvedl(m=1:MMAX,t=1:TMAX)         ! Antall maskiner av typen t nede for
                                 ! vedlikehold i perioden m
! ***************************************************************************
CONSTRAINTS
!
! Objektfunksjonen: maks. profitt, dvs. maks av produksjon*nettoverdi
! minus lagringskostnader
!
 MAXOBJ:                                                                     &
 SUM(m=1:MMAX,p=1:PMAX) PRO(p) * skvant(m,p) -                               &
 SUM(m=1:MMAX,p=1:PMAX) KLAG * lkvant(m,p)                                   $
!
! "Massebalanse": for hvert produkt p over hver periode p gjelder
! lagr.mengde(m-1,p) + prod.mengde(m,p) = solgt mengde(m,p) + lagr.mengde(m,p)
! Dette gjelder for alle perioder untatt en bestemt, hvor man skal tilfredst.
! en viss lagringsmengde, og den foerste, hvor lageret er tomt
!
 MAB0(p=1:PMAX):                                                           &
 pkvant(1,p) - skvant(1,p) - lkvant(1,p) = 0     
!
 MABAL(p=1:PMAX,m=2:MMAX):                                                  &
 lkvant(m-1,p) + pkvant(m,p) - skvant(m,p) - lkvant(m,p) = 0     
!
! Prosesseringstid: det er ikke mer tilgjengelig prosesseringstid for hver
! maskintype t i tidsperioden m enn ant.maskiner i produksjon, (dvs. maks
! antall minus maskiner til vedlikehold) multiplisert med tidsforbruk
! for hver individuell maskin. Restriksjonen deles inn i tre deler hvor (1)
! gjelder for problem 12.3, og (2)/(3) for problem 12.4
!
! (1)
 PROSTID(t=1:TMAX,m=1:MMAX | MOD.eq.1):                                                &    
 SUM(p=1:PMAX) TID(t,p) * pkvant(m,p)   <                                   &
 TPRM*(ANTMA(t) - VED(m,t)) 
!
! (2)
 PROTID(t=1:TMAX,m=1:MMAX | MOD.eq.0):                                                &    
 SUM(p=1:PMAX) TID(t,p) * pkvant(m,p)   <                                   &
 TPRM*ANTMA(t) - TPRM*mvedl(m,t)
!
! (3a): maskin 1
 MASK1( | MOD.eq.0):                                                        &
 SUM(m=1:MMAX) mvedl(m,1) = 2
! (3b): maskin 2-5
 MASK15(t=2:TMAX | MOD.eq.0):                                               &
 SUM(m=1:MMAX) mvedl(m,t) = ANTMA(t)
!
! Paatvungen lagringsmengde ved periode m:
 TVUNGETL(n=1:NMAX,p=1:PMAX):                                               &
 lkvant(BEH(n,2),p) = BEH(n,1)
!
!
! **************************************************************************
BOUNDS
!
! Maksimal lagringsmengde for produkt p uansett periode m:
!
 lkvant(m=1:MMAX,p=1:PMAX) < MLKAP
!
! Markedsrestriksjoner: kan ikke selge mer av produkt p i periode m enn
! det markedet er villig til aa kjoepe:
!
 skvant(m=1:MMAX,p=1:PMAX) < MABE(m,p) 
!
 mvedl(m=1:MMAX,t=1:2 | MOD .eq. 0) .UI. 2                                     &
!
 mvedl(m=1:MMAX,3 | MOD .eq. 0) .UI. 3                                       &
!
 mvedl(m=1:MMAX,t=4:TMAX | MOD .eq. 0) .UI. 1                                  &
!
GENERATE
